@@ -3,8 +3,8 @@
  * gnome-db2html3 - by John Fleck - based on Daniel Veillard's
  * xsltproc: user program for the XSL Transformation engine
  * 
- * Copyright (C) John Fleck, 2001
- * Copyright (C) Mikael Hallendal, 2002
+ * Copyright (C) 2001 John Fleck        <jfleck@inkstain.net>
+ * Copyright (C) 2002 Mikael Hallendal  <micke@imendio.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,6 +42,7 @@
 #include <libxslt/xsltInternals.h>
 #include <libxslt/transform.h>
 #include <libxslt/xsltutils.h>
+#include <libexslt/exslt.h>
 
 #include "yelp-error.h"
 
@@ -76,10 +77,18 @@ main (gint argc, gchar **argv)
 
         docpath = argv[1];
 
+	if (!g_file_test (docpath, G_FILE_TEST_EXISTS)) {
+		g_warning ("'%s' doesn't exist.", docpath);
+		exit (1);
+	}
+
 	/* libxml housekeeping */
 	xmlSubstituteEntitiesDefault(1);
 	xmlLoadExtDtdDefaultValue = 1;
 
+	/* Register the EXSLT extentions */
+	exsltRegisterAll();
+
 	/* parse the stylesheet */
         stylesheet  = xsltParseStylesheetFile (STYLESHEET);
         
@@ -106,7 +115,7 @@ main (gint argc, gchar **argv)
 	/* retrieve path component of filename passed in at
 	   command line */
 	pathname = g_path_get_dirname (docpath);
-        
+
 	/* set params to be passed to stylesheet */
 	params[0] = "gdb_docname";
 	params[1] = g_strconcat("\"", docpath, "\"", NULL) ;
